%define pypi_name tornado

Name:           python-%{pypi_name}
Version:        6.3.2
Release:        %mkrel 1
Summary:        Scalable, non-blocking web server and tools

Group:          Development/Python
License:        ASL 2.0
URL:            https://pypi.org/project/tornado/
Source0:        %{pypi_source}
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(certifi)
BuildRequires:  python3dist(pycares)
BuildRequires:  python3dist(pycurl)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(twisted)

%description
Tornado is an open source version of the scalable, non-blocking web server and
and tools.

The framework is distinct from most mainstream web server frameworks (and
certainly most Python frameworks) because it is non-blocking and reasonably
fast. Because it is non-blocking and uses epoll, it can handle thousands of
simultaneous standing connections, which means it is ideal for real-time web
services.

%package -n python3-%{pypi_name}
Summary:        Scalable, non-blocking web server and tools
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:	python3dist(pycurl)
Requires:	python3dist(simplejson)

%description -n python3-%{pypi_name}
Tornado is an open source version of the scalable, non-blocking web
server and tools.

The framework is distinct from most mainstream web server frameworks
(and certainly most Python frameworks) because it is non-blocking and
reasonably fast. Because it is non-blocking and uses epoll, it can
handle thousands of simultaneous standing connections, which means it is
ideal for real-time web services.

%package -n python3-%{pypi_name}-doc
Summary:        Examples for python-tornado
Group:          Development/Python
Requires:       python3-tornado = %{version}-%{release}

%description -n python3-%{pypi_name}-doc
Tornado is an open source version of the scalable, non-blocking web
server and and tools. This package contains some example applications.

%prep
%autosetup  -n %{pypi_name}-%{version}

# remove shebang from files
%{__sed} -i.orig -e '/^#!\//, 1d' *py tornado/*.py tornado/*/*.py

# spurious permission fix
find demos/ -name "*.py" -exec chmod -x {} \;

# remove empty file
rm -rf demos/facebook/static/facebook.js

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files tornado

%check
PYTHONPATH=%{buildroot}%{python3_sitearch} \
%{__python3} -m tornado.test.runtests --verbose || :

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.rst PKG-INFO

%files -n python3-%{pypi_name}-doc
%doc demos


%changelog
* Tue Jun 20 2023 daviddavid <daviddavid> 6.3.2-1.mga9
+ Revision: 1962634
- new version: 6.3.2, fixes CVE-2023-28370 (mga#32033)

* Thu Sep 08 2022 neoclust <neoclust> 6.2-1.mga9
+ Revision: 1885910
- New version  6.2.0

* Tue Mar 29 2022 umeabot <umeabot> 6.1-4.mga9
+ Revision: 1833213
- Mageia 9 Mass Rebuild

* Fri Feb 11 2022 wally <wally> 6.1-3.mga9
+ Revision: 1772926
- rebuild for python3.10

* Sun Mar 21 2021 daviddavid <daviddavid> 6.1-2.mga9
+ Revision: 1707042
- rebuild for python 3.9

* Sun Nov 08 2020 guillomovitch <guillomovitch> 6.1-1.mga8
+ Revision: 1643738
- new version 6.1

* Sun Mar 29 2020 wally <wally> 6.0.4-1.mga8
+ Revision: 1562182
- new version 6.0.4

* Tue Feb 18 2020 umeabot <umeabot> 6.0.3-2.mga8
+ Revision: 1538421
- Mageia 8 Mass Rebuild

* Wed Nov 20 2019 daviddavid <daviddavid> 6.0.3-1.mga8
+ Revision: 1461841
- new version: 6.0.3

* Thu Oct 10 2019 daviddavid <daviddavid> 6.0.2-1.mga8
+ Revision: 1450935
- new version: 6.0.2

* Mon Sep 16 2019 daviddavid <daviddavid> 5.1.1-2.mga8
+ Revision: 1442270
- rebuild for python3.8
- drop python2 support

* Mon Jan 07 2019 wally <wally> 5.1.1-1.mga7
+ Revision: 1351199
- new version 5.1.1

* Mon Jan 07 2019 wally <wally> 5.0.2-3.mga7
+ Revision: 1350944
- rebuild for python3.7
- update (build)requires

* Sun Sep 23 2018 umeabot <umeabot> 5.0.2-2.mga7
+ Revision: 1300613
- Mageia 7 Mass Rebuild

* Fri Apr 20 2018 kekepower <kekepower> 5.0.2-1.mga7
+ Revision: 1220399
- Update to version 5.0.2
- Rename python-tornado to python2-tornado
- Use python_provide

* Sat Aug 05 2017 pterjan <pterjan> 4.4.2-2.mga7
+ Revision: 1135665
- Rebuild for python 3.6

* Tue Nov 29 2016 philippem <philippem> 4.4.2-1.mga6
+ Revision: 1070932
- update to 4.4.2
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Nov 18 2015 joequant <joequant> 4.3-1.mga6
+ Revision: 903940
- upgrade to 4.3

* Wed Oct 07 2015 tv <tv> 4.2.1-3.mga6
+ Revision: 886999
- rebuild for python 3.5

* Tue Sep 29 2015 joequant <joequant> 4.2.1-2.mga6
+ Revision: 884959
- clean up spec

* Thu Sep 24 2015 philippem <philippem> 4.2.1-1.mga6
+ Revision: 883351
- update to 4.2.1

* Tue Jun 30 2015 joequant <joequant> 4.2-1.mga6
+ Revision: 848343
- upgrade to 4.2

* Wed Oct 15 2014 umeabot <umeabot> 3.2.2-4.mga5
+ Revision: 749948
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.2.2-3.mga5
+ Revision: 729885
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.2.2-2.mga5
+ Revision: 688383
- Mageia 5 Mass Rebuild

* Fri Jun 20 2014 philippem <philippem> 3.2.2-1.mga5
+ Revision: 638207
- update to 3.2.2

* Sat May 31 2014 pterjan <pterjan> 3.2-2.mga5
+ Revision: 629061
- Rebuild for new Python

* Tue Mar 04 2014 philippem <philippem> 3.2-1.mga5
+ Revision: 599553
- update to 3.2, adding c extension

* Sat Nov 30 2013 philippem <philippem> 3.1-4.mga4
+ Revision: 554151
- change-match_hostname-to-follow-RFC-6125 (mga#11785)

* Tue Oct 22 2013 umeabot <umeabot> 3.1-3.mga4
+ Revision: 544350
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 3.1-2.mga4
+ Revision: 499568
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Jul 05 2013 philippem <philippem> 3.1-1.mga4
+ Revision: 450335
- Update to 3.1, add Python 3

* Fri Jun 07 2013 philippem <philippem> 2.3-2.1.mga4
+ Revision: 440324
- fix CVE-2013-2099 (ssl.match_hostname DOS)

* Sun Jan 13 2013 umeabot <umeabot> 2.3-2.mga3
+ Revision: 379574
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jun 09 2012 wally <wally> 2.3-1.mga3
+ Revision: 258360
- new version 2.3

* Mon Dec 19 2011 lebedov <lebedov> 2.1.1-2.mga2
+ Revision: 184420
- imported package python-tornado

